Class: Google::Apis::AuthorizedbuyersmarketplaceV1::Client

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb

Overview

A client represents an agency, a brand, or an advertiser customer of the buyer. Based on the client's role, its client users will have varying levels of restricted access to the Marketplace and certain other sections of the Authorized Buyers UI.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Client

Returns a new instance of Client.



342
343
344
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 342

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Required. Display name shown to publishers. Must be unique for clients without partnerClientId specified. Maximum length of 255 characters is allowed. Corresponds to the JSON property displayName

Returns:

  • (String)


309
310
311
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 309

def display_name
  @display_name
end

#nameString

Output only. The resource name of the client. Format: buyers/accountId/ clients/clientAccountId` Corresponds to the JSON propertyname`

Returns:

  • (String)


315
316
317
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 315

def name
  @name
end

#partner_client_idString

Arbitrary unique identifier provided by the buyer. This field can be used to associate a client with an identifier in the namespace of the buyer, lookup clients by that identifier and verify whether an Authorized Buyers account of the client already exists. If present, must be unique across all the clients. Corresponds to the JSON property partnerClientId

Returns:

  • (String)


323
324
325
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 323

def partner_client_id
  @partner_client_id
end

#roleString

Required. The role assigned to the client. Each role implies a set of permissions granted to the client. Corresponds to the JSON property role

Returns:

  • (String)


329
330
331
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 329

def role
  @role
end

#seller_visibleBoolean Also known as: seller_visible?

Whether the client will be visible to sellers. Corresponds to the JSON property sellerVisible

Returns:

  • (Boolean)


334
335
336
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 334

def seller_visible
  @seller_visible
end

#stateString

Output only. The state of the client. Corresponds to the JSON property state

Returns:

  • (String)


340
341
342
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 340

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



347
348
349
350
351
352
353
354
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 347

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @partner_client_id = args[:partner_client_id] if args.key?(:partner_client_id)
  @role = args[:role] if args.key?(:role)
  @seller_visible = args[:seller_visible] if args.key?(:seller_visible)
  @state = args[:state] if args.key?(:state)
end