Class: Google::Apis::AuthorizedbuyersmarketplaceV1::CreativeRequirements

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb

Overview

Message captures data about the creatives in the deal.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreativeRequirements

Returns a new instance of CreativeRequirements.



456
457
458
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 456

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creative_formatString

Output only. The format of the creative, only applicable for programmatic guaranteed and preferred deals. Corresponds to the JSON property creativeFormat

Returns:

  • (String)


425
426
427
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 425

def creative_format
  @creative_format
end

#creative_pre_approval_policyString

Output only. Specifies the creative pre-approval policy. Corresponds to the JSON property creativePreApprovalPolicy

Returns:

  • (String)


430
431
432
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 430

def creative_pre_approval_policy
  @creative_pre_approval_policy
end

#creative_safe_frame_compatibilityString

Output only. Specifies whether the creative is safeFrame compatible. Corresponds to the JSON property creativeSafeFrameCompatibility

Returns:

  • (String)


435
436
437
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 435

def creative_safe_frame_compatibility
  @creative_safe_frame_compatibility
end

#max_ad_duration_msFixnum

Output only. The max duration of the video creative in milliseconds. only applicable for deals with video creatives. Corresponds to the JSON property maxAdDurationMs

Returns:

  • (Fixnum)


441
442
443
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 441

def max_ad_duration_ms
  @max_ad_duration_ms
end

#programmatic_creative_sourceString

Output only. Specifies the creative source for programmatic deals. PUBLISHER means creative is provided by seller and ADVERTISER means creative is provided by the buyer. Corresponds to the JSON property programmaticCreativeSource

Returns:

  • (String)


448
449
450
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 448

def programmatic_creative_source
  @programmatic_creative_source
end

#skippable_ad_typeString

Output only. Skippable video ads allow viewers to skip ads after 5 seconds. Only applicable for deals with video creatives. Corresponds to the JSON property skippableAdType

Returns:

  • (String)


454
455
456
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 454

def skippable_ad_type
  @skippable_ad_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



461
462
463
464
465
466
467
468
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 461

def update!(**args)
  @creative_format = args[:creative_format] if args.key?(:creative_format)
  @creative_pre_approval_policy = args[:creative_pre_approval_policy] if args.key?(:creative_pre_approval_policy)
  @creative_safe_frame_compatibility = args[:creative_safe_frame_compatibility] if args.key?(:creative_safe_frame_compatibility)
  @max_ad_duration_ms = args[:max_ad_duration_ms] if args.key?(:max_ad_duration_ms)
  @programmatic_creative_source = args[:programmatic_creative_source] if args.key?(:programmatic_creative_source)
  @skippable_ad_type = args[:skippable_ad_type] if args.key?(:skippable_ad_type)
end