Class: Google::Apis::AuthorizedbuyersmarketplaceV1::DayPart
- Inherits:
-
Object
- Object
- Google::Apis::AuthorizedbuyersmarketplaceV1::DayPart
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb
Overview
Defines targeting for a period of time on a specific week day.
Instance Attribute Summary collapse
-
#day_of_week ⇒ String
Day of week for the period.
-
#end_time ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1::TimeOfDay
Represents a time of day.
-
#start_time ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1::TimeOfDay
Represents a time of day.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DayPart
constructor
A new instance of DayPart.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DayPart
Returns a new instance of DayPart.
521 522 523 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 521 def initialize(**args) update!(**args) end |
Instance Attribute Details
#day_of_week ⇒ String
Day of week for the period.
Corresponds to the JSON property dayOfWeek
505 506 507 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 505 def day_of_week @day_of_week end |
#end_time ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property endTime
512 513 514 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 512 def end_time @end_time end |
#start_time ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property startTime
519 520 521 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 519 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
526 527 528 529 530 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 526 def update!(**args) @day_of_week = args[:day_of_week] if args.key?(:day_of_week) @end_time = args[:end_time] if args.key?(:end_time) @start_time = args[:start_time] if args.key?(:start_time) end |