Class: Google::Apis::AuthorizedbuyersmarketplaceV1::Deal

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb

Overview

A deal represents a segment of inventory for displaying ads that contains the terms and targeting information that is used for serving as well as the deal stats and status. Note: A proposal may contain multiple deals.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Deal

Returns a new instance of Deal.



736
737
738
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 736

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#billed_buyerString

Output only. When the client field is populated, this field refers to the buyer who creates and manages the client buyer and gets billed on behalf of the client buyer; when the buyer field is populated, this field is the same value as buyer; when the deal belongs to a media planner account, this field will be empty. Format : buyers/buyerAccountId` Corresponds to the JSON propertybilledBuyer`

Returns:

  • (String)


597
598
599
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 597

def billed_buyer
  @billed_buyer
end

#buyerString

Output only. Refers to a buyer in Real-time Bidding API's Buyer resource. Format: buyers/buyerAccountId` Corresponds to the JSON propertybuyer`

Returns:

  • (String)


603
604
605
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 603

def buyer
  @buyer
end

#buyer_permission_typeString

Output only. The buyer permission type of the deal. Corresponds to the JSON property buyerPermissionType

Returns:

  • (String)


608
609
610
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 608

def buyer_permission_type
  @buyer_permission_type
end

#clientString

Output only. Refers to a Client. Format: buyers/buyerAccountId/clients/ clientAccountid` Corresponds to the JSON propertyclient`

Returns:

  • (String)


614
615
616
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 614

def client
  @client
end

#create_timeString

Output only. The time of the deal creation. Corresponds to the JSON property createTime

Returns:

  • (String)


619
620
621
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 619

def create_time
  @create_time
end

#creative_requirementsGoogle::Apis::AuthorizedbuyersmarketplaceV1::CreativeRequirements

Message captures data about the creatives in the deal. Corresponds to the JSON property creativeRequirements



624
625
626
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 624

def creative_requirements
  @creative_requirements
end

#deal_typeString

Output only. Type of deal. Corresponds to the JSON property dealType

Returns:

  • (String)


629
630
631
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 629

def deal_type
  @deal_type
end

#delivery_controlGoogle::Apis::AuthorizedbuyersmarketplaceV1::DeliveryControl

Message contains details about how the deal will be paced. Corresponds to the JSON property deliveryControl



634
635
636
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 634

def delivery_control
  @delivery_control
end

#descriptionString

Output only. Free text description for the deal terms. Corresponds to the JSON property description

Returns:

  • (String)


639
640
641
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 639

def description
  @description
end

#display_nameString

Output only. The name of the deal. Maximum length of 255 unicode characters is allowed. Control characters are not allowed. Buyers cannot update this field. Note: Not to be confused with name, which is a unique identifier of the deal. Corresponds to the JSON property displayName

Returns:

  • (String)


646
647
648
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 646

def display_name
  @display_name
end

#eligible_seat_idsArray<String>

Output only. If set, this field contains the list of DSP specific seat ids set by media planners that are eligible to transact on this deal. The seat ID is in the calling DSP's namespace. Corresponds to the JSON property eligibleSeatIds

Returns:

  • (Array<String>)


653
654
655
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 653

def eligible_seat_ids
  @eligible_seat_ids
end

#estimated_gross_spendGoogle::Apis::AuthorizedbuyersmarketplaceV1::Money

Represents an amount of money with its currency type. Corresponds to the JSON property estimatedGrossSpend



658
659
660
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 658

def estimated_gross_spend
  @estimated_gross_spend
end

#flight_end_timeString

Proposed flight end time of the deal. This will generally be stored in a granularity of a second. A value is not necessary for Private Auction deals. Corresponds to the JSON property flightEndTime

Returns:

  • (String)


664
665
666
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 664

def flight_end_time
  @flight_end_time
end

#flight_start_timeString

Proposed flight start time of the deal. This will generally be stored in the granularity of one second since deal serving starts at seconds boundary. Any time specified with more granularity (for example, in milliseconds) will be truncated towards the start of time in seconds. Corresponds to the JSON property flightStartTime

Returns:

  • (String)


672
673
674
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 672

def flight_start_time
  @flight_start_time
end

#media_plannerGoogle::Apis::AuthorizedbuyersmarketplaceV1::MediaPlanner

Represents a media planner account. Corresponds to the JSON property mediaPlanner



677
678
679
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 677

def media_planner
  @media_planner
end

#nameString

Immutable. The unique identifier of the deal. Auto-generated by the server when a deal is created. Format: buyers/accountId/proposals/proposalId/ deals/dealId Corresponds to the JSON property name

Returns:

  • (String)


684
685
686
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 684

def name
  @name
end

#preferred_deal_termsGoogle::Apis::AuthorizedbuyersmarketplaceV1::PreferredDealTerms

Pricing terms for Preferred Deals. Corresponds to the JSON property preferredDealTerms



689
690
691
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 689

def preferred_deal_terms
  @preferred_deal_terms
end

#private_auction_termsGoogle::Apis::AuthorizedbuyersmarketplaceV1::PrivateAuctionTerms

Pricing terms for Private Auctions. Corresponds to the JSON property privateAuctionTerms



694
695
696
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 694

def private_auction_terms
  @private_auction_terms
end

#programmatic_guaranteed_termsGoogle::Apis::AuthorizedbuyersmarketplaceV1::ProgrammaticGuaranteedTerms

Pricing terms for Programmatic Guaranteed Deals. Corresponds to the JSON property programmaticGuaranteedTerms



699
700
701
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 699

def programmatic_guaranteed_terms
  @programmatic_guaranteed_terms
end

#proposal_revisionFixnum

Output only. The revision number for the proposal and is the same value as proposal.proposal_revision. Each update to deal causes the proposal revision number to auto-increment. The buyer keeps track of the last revision number they know of and pass it in when making an update. If the head revision number on the server has since incremented, then an ABORTED error is returned during the update operation to let the buyer know that a subsequent update was made. Corresponds to the JSON property proposalRevision

Returns:

  • (Fixnum)


709
710
711
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 709

def proposal_revision
  @proposal_revision
end

#publisher_profileString

Immutable. Reference to the seller on the deal. Format: buyers/ buyerAccountId/publisherProfiles/publisherProfileId` Corresponds to the JSON propertypublisherProfile`

Returns:

  • (String)


715
716
717
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 715

def publisher_profile
  @publisher_profile
end

#seller_time_zoneGoogle::Apis::AuthorizedbuyersmarketplaceV1::TimeZone

Represents a time zone from the IANA Time Zone Database. Corresponds to the JSON property sellerTimeZone



721
722
723
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 721

def seller_time_zone
  @seller_time_zone
end

#targetingGoogle::Apis::AuthorizedbuyersmarketplaceV1::MarketplaceTargeting

Targeting represents different criteria that can be used to target deals or auction packages. For example, they can choose to target inventory only if the user is in the US. Multiple types of targeting are always applied as a logical AND, unless noted otherwise. Corresponds to the JSON property targeting



729
730
731
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 729

def targeting
  @targeting
end

#update_timeString

Output only. The time when the deal was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


734
735
736
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 734

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 741

def update!(**args)
  @billed_buyer = args[:billed_buyer] if args.key?(:billed_buyer)
  @buyer = args[:buyer] if args.key?(:buyer)
  @buyer_permission_type = args[:buyer_permission_type] if args.key?(:buyer_permission_type)
  @client = args[:client] if args.key?(:client)
  @create_time = args[:create_time] if args.key?(:create_time)
  @creative_requirements = args[:creative_requirements] if args.key?(:creative_requirements)
  @deal_type = args[:deal_type] if args.key?(:deal_type)
  @delivery_control = args[:delivery_control] if args.key?(:delivery_control)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @eligible_seat_ids = args[:eligible_seat_ids] if args.key?(:eligible_seat_ids)
  @estimated_gross_spend = args[:estimated_gross_spend] if args.key?(:estimated_gross_spend)
  @flight_end_time = args[:flight_end_time] if args.key?(:flight_end_time)
  @flight_start_time = args[:flight_start_time] if args.key?(:flight_start_time)
  @media_planner = args[:media_planner] if args.key?(:media_planner)
  @name = args[:name] if args.key?(:name)
  @preferred_deal_terms = args[:preferred_deal_terms] if args.key?(:preferred_deal_terms)
  @private_auction_terms = args[:private_auction_terms] if args.key?(:private_auction_terms)
  @programmatic_guaranteed_terms = args[:programmatic_guaranteed_terms] if args.key?(:programmatic_guaranteed_terms)
  @proposal_revision = args[:proposal_revision] if args.key?(:proposal_revision)
  @publisher_profile = args[:publisher_profile] if args.key?(:publisher_profile)
  @seller_time_zone = args[:seller_time_zone] if args.key?(:seller_time_zone)
  @targeting = args[:targeting] if args.key?(:targeting)
  @update_time = args[:update_time] if args.key?(:update_time)
end