Class: Google::Apis::AuthorizedbuyersmarketplaceV1::FinalizedDeal

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb

Overview

A finalized deal is a snapshot of the deal when both buyer and seller accept the deal. The buyer or seller can update the deal after it's been finalized and renegotiate on the deal targeting, terms and other fields, while at the same time the finalized snapshot of the deal can still be retrieved using this API. The finalized deal contains a copy of the deal as it existed when most recently finalized, as well as fields related to deal serving such as pause/ resume status, RTB metrics, and more.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FinalizedDeal

Returns a new instance of FinalizedDeal.



907
908
909
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 907

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dealGoogle::Apis::AuthorizedbuyersmarketplaceV1::Deal

A deal represents a segment of inventory for displaying ads that contains the terms and targeting information that is used for serving as well as the deal stats and status. Note: A proposal may contain multiple deals. Corresponds to the JSON property deal



877
878
879
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 877

def deal
  @deal
end

#deal_pausing_infoGoogle::Apis::AuthorizedbuyersmarketplaceV1::DealPausingInfo

Information related to deal pausing. Corresponds to the JSON property dealPausingInfo



882
883
884
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 882

def deal_pausing_info
  @deal_pausing_info
end

#deal_serving_statusString

Serving status of the deal. Corresponds to the JSON property dealServingStatus

Returns:

  • (String)


887
888
889
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 887

def deal_serving_status
  @deal_serving_status
end

#nameString

The resource name of the finalized deal. Format: buyers/accountId/ finalizedDeals/finalizedDealId` Corresponds to the JSON propertyname`

Returns:

  • (String)


893
894
895
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 893

def name
  @name
end

#ready_to_serveBoolean Also known as: ready_to_serve?

Whether the Programmatic Guaranteed deal is ready for serving. Corresponds to the JSON property readyToServe

Returns:

  • (Boolean)


898
899
900
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 898

def ready_to_serve
  @ready_to_serve
end

#rtb_metricsGoogle::Apis::AuthorizedbuyersmarketplaceV1::RtbMetrics

Real-time bidding metrics. For what each metric means refer to Report metrics Corresponds to the JSON property rtbMetrics



905
906
907
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 905

def rtb_metrics
  @rtb_metrics
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



912
913
914
915
916
917
918
919
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 912

def update!(**args)
  @deal = args[:deal] if args.key?(:deal)
  @deal_pausing_info = args[:deal_pausing_info] if args.key?(:deal_pausing_info)
  @deal_serving_status = args[:deal_serving_status] if args.key?(:deal_serving_status)
  @name = args[:name] if args.key?(:name)
  @ready_to_serve = args[:ready_to_serve] if args.key?(:ready_to_serve)
  @rtb_metrics = args[:rtb_metrics] if args.key?(:rtb_metrics)
end