Class: Google::Apis::AuthorizedbuyersmarketplaceV1::MarketplaceTargeting
- Inherits:
-
Object
- Object
- Google::Apis::AuthorizedbuyersmarketplaceV1::MarketplaceTargeting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb
Overview
Targeting represents different criteria that can be used to target deals or auction packages. For example, they can choose to target inventory only if the user is in the US. Multiple types of targeting are always applied as a logical AND, unless noted otherwise.
Instance Attribute Summary collapse
-
#daypart_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1::DayPartTargeting
Represents Daypart targeting.
-
#excluded_sensitive_category_ids ⇒ Array<Fixnum>
Output only.
-
#geo_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1::CriteriaTargeting
Generic targeting used for targeting dimensions that contains a list of included and excluded numeric IDs.
-
#inventory_size_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1::InventorySizeTargeting
Represents the size of an ad unit that can be targeted on a bid request.
-
#inventory_type_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1::InventoryTypeTargeting
Targeting of the inventory types a bid request can originate from.
-
#placement_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1::PlacementTargeting
Represents targeting about where the ads can appear, for example, certain sites or mobile applications.
-
#technology_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1::TechnologyTargeting
Represents targeting about various types of technology.
-
#user_list_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1::CriteriaTargeting
Generic targeting used for targeting dimensions that contains a list of included and excluded numeric IDs.
-
#vertical_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1::CriteriaTargeting
Generic targeting used for targeting dimensions that contains a list of included and excluded numeric IDs.
-
#video_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1::VideoTargeting
Represents targeting information about video.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MarketplaceTargeting
constructor
A new instance of MarketplaceTargeting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MarketplaceTargeting
Returns a new instance of MarketplaceTargeting.
1277 1278 1279 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1277 def initialize(**args) update!(**args) end |
Instance Attribute Details
#daypart_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1::DayPartTargeting
Represents Daypart targeting.
Corresponds to the JSON property daypartTargeting
1220 1221 1222 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1220 def daypart_targeting @daypart_targeting end |
#excluded_sensitive_category_ids ⇒ Array<Fixnum>
Output only. The sensitive content category label IDs excluded. Refer to this
file https://storage.googleapis.com/adx-rtb-dictionaries/content-labels.txt
for category IDs.
Corresponds to the JSON property excludedSensitiveCategoryIds
1227 1228 1229 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1227 def excluded_sensitive_category_ids @excluded_sensitive_category_ids end |
#geo_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1::CriteriaTargeting
Generic targeting used for targeting dimensions that contains a list of
included and excluded numeric IDs. This cannot be filtered using list filter
syntax.
Corresponds to the JSON property geoTargeting
1234 1235 1236 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1234 def geo_targeting @geo_targeting end |
#inventory_size_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1::InventorySizeTargeting
Represents the size of an ad unit that can be targeted on a bid request.
Corresponds to the JSON property inventorySizeTargeting
1239 1240 1241 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1239 def inventory_size_targeting @inventory_size_targeting end |
#inventory_type_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1::InventoryTypeTargeting
Targeting of the inventory types a bid request can originate from.
Corresponds to the JSON property inventoryTypeTargeting
1244 1245 1246 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1244 def inventory_type_targeting @inventory_type_targeting end |
#placement_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1::PlacementTargeting
Represents targeting about where the ads can appear, for example, certain
sites or mobile applications. Different placement targeting types will be
logically OR'ed.
Corresponds to the JSON property placementTargeting
1251 1252 1253 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1251 def placement_targeting @placement_targeting end |
#technology_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1::TechnologyTargeting
Represents targeting about various types of technology.
Corresponds to the JSON property technologyTargeting
1256 1257 1258 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1256 def technology_targeting @technology_targeting end |
#user_list_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1::CriteriaTargeting
Generic targeting used for targeting dimensions that contains a list of
included and excluded numeric IDs. This cannot be filtered using list filter
syntax.
Corresponds to the JSON property userListTargeting
1263 1264 1265 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1263 def user_list_targeting @user_list_targeting end |
#vertical_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1::CriteriaTargeting
Generic targeting used for targeting dimensions that contains a list of
included and excluded numeric IDs. This cannot be filtered using list filter
syntax.
Corresponds to the JSON property verticalTargeting
1270 1271 1272 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1270 def vertical_targeting @vertical_targeting end |
#video_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1::VideoTargeting
Represents targeting information about video.
Corresponds to the JSON property videoTargeting
1275 1276 1277 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1275 def video_targeting @video_targeting end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1282 1283 1284 1285 1286 1287 1288 1289 1290 1291 1292 1293 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1282 def update!(**args) @daypart_targeting = args[:daypart_targeting] if args.key?(:daypart_targeting) @excluded_sensitive_category_ids = args[:excluded_sensitive_category_ids] if args.key?(:excluded_sensitive_category_ids) @geo_targeting = args[:geo_targeting] if args.key?(:geo_targeting) @inventory_size_targeting = args[:inventory_size_targeting] if args.key?(:inventory_size_targeting) @inventory_type_targeting = args[:inventory_type_targeting] if args.key?(:inventory_type_targeting) @placement_targeting = args[:placement_targeting] if args.key?(:placement_targeting) @technology_targeting = args[:technology_targeting] if args.key?(:technology_targeting) @user_list_targeting = args[:user_list_targeting] if args.key?(:user_list_targeting) @vertical_targeting = args[:vertical_targeting] if args.key?(:vertical_targeting) @video_targeting = args[:video_targeting] if args.key?(:video_targeting) end |