Class: Google::Apis::AuthorizedbuyersmarketplaceV1::MediaPlanner

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb

Overview

Represents a media planner account.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MediaPlanner

Returns a new instance of MediaPlanner.



1325
1326
1327
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1325

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idString

Output only. Account ID of the media planner. Corresponds to the JSON property accountId

Returns:

  • (String)


1303
1304
1305
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1303

def 
  @account_id
end

#ancestor_namesArray<String>

Output only. The ancestor names of the media planner. Format: mediaPlanners/ mediaPlannerAccountId`Can be used to filter the response of the mediaPlanners.list method. Corresponds to the JSON propertyancestorNames`

Returns:

  • (Array<String>)


1310
1311
1312
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1310

def ancestor_names
  @ancestor_names
end

#display_nameString

Output only. The display name of the media planner. Can be used to filter the response of the mediaPlanners.list method. Corresponds to the JSON property displayName

Returns:

  • (String)


1316
1317
1318
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1316

def display_name
  @display_name
end

#nameString

Identifier. The unique resource name of the media planner. Format: mediaPlanners/mediaPlannerAccountId`Can be used to filter the response of the mediaPlanners.list method. Corresponds to the JSON propertyname`

Returns:

  • (String)


1323
1324
1325
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1323

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1330
1331
1332
1333
1334
1335
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1330

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @ancestor_names = args[:ancestor_names] if args.key?(:ancestor_names)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
end