Class: Google::Apis::AuthorizedbuyersmarketplaceV1::OperatingSystemTargeting
- Inherits:
-
Object
- Object
- Google::Apis::AuthorizedbuyersmarketplaceV1::OperatingSystemTargeting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb
Overview
Represents targeting information for operating systems.
Instance Attribute Summary collapse
-
#operating_system_criteria ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1::CriteriaTargeting
Generic targeting used for targeting dimensions that contains a list of included and excluded numeric IDs.
-
#operating_system_version_criteria ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1::CriteriaTargeting
Generic targeting used for targeting dimensions that contains a list of included and excluded numeric IDs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperatingSystemTargeting
constructor
A new instance of OperatingSystemTargeting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperatingSystemTargeting
Returns a new instance of OperatingSystemTargeting.
1447 1448 1449 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1447 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operating_system_criteria ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1::CriteriaTargeting
Generic targeting used for targeting dimensions that contains a list of
included and excluded numeric IDs. This cannot be filtered using list filter
syntax.
Corresponds to the JSON property operatingSystemCriteria
1438 1439 1440 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1438 def @operating_system_criteria end |
#operating_system_version_criteria ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1::CriteriaTargeting
Generic targeting used for targeting dimensions that contains a list of
included and excluded numeric IDs. This cannot be filtered using list filter
syntax.
Corresponds to the JSON property operatingSystemVersionCriteria
1445 1446 1447 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1445 def @operating_system_version_criteria end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1452 1453 1454 1455 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1452 def update!(**args) @operating_system_criteria = args[:operating_system_criteria] if args.key?(:operating_system_criteria) @operating_system_version_criteria = args[:operating_system_version_criteria] if args.key?(:operating_system_version_criteria) end |