Class: Google::Apis::AuthorizedbuyersmarketplaceV1::PreferredDealTerms
- Inherits:
-
Object
- Object
- Google::Apis::AuthorizedbuyersmarketplaceV1::PreferredDealTerms
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb
Overview
Pricing terms for Preferred Deals.
Instance Attribute Summary collapse
-
#fixed_price ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1::Price
Represents a price and a pricing type for a deal.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PreferredDealTerms
constructor
A new instance of PreferredDealTerms.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PreferredDealTerms
Returns a new instance of PreferredDealTerms.
1516 1517 1518 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1516 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fixed_price ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1::Price
Represents a price and a pricing type for a deal.
Corresponds to the JSON property fixedPrice
1514 1515 1516 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1514 def fixed_price @fixed_price end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1521 1522 1523 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1521 def update!(**args) @fixed_price = args[:fixed_price] if args.key?(:fixed_price) end |