Class: Google::Apis::AuthorizedbuyersmarketplaceV1::Price

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb

Overview

Represents a price and a pricing type for a deal.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Price

Returns a new instance of Price.



1540
1541
1542
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1540

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#amountGoogle::Apis::AuthorizedbuyersmarketplaceV1::Money

Represents an amount of money with its currency type. Corresponds to the JSON property amount



1533
1534
1535
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1533

def amount
  @amount
end

#typeString

The pricing type for the deal. Corresponds to the JSON property type

Returns:

  • (String)


1538
1539
1540
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1538

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1545
1546
1547
1548
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1545

def update!(**args)
  @amount = args[:amount] if args.key?(:amount)
  @type = args[:type] if args.key?(:type)
end