Class: Google::Apis::AuthorizedbuyersmarketplaceV1::PrivateAuctionTerms

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb

Overview

Pricing terms for Private Auctions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PrivateAuctionTerms

Returns a new instance of PrivateAuctionTerms.



1567
1568
1569
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1567

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#floor_priceGoogle::Apis::AuthorizedbuyersmarketplaceV1::Price

Represents a price and a pricing type for a deal. Corresponds to the JSON property floorPrice



1558
1559
1560
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1558

def floor_price
  @floor_price
end

#open_auction_allowedBoolean Also known as: open_auction_allowed?

Output only. True if open auction buyers are allowed to compete with invited buyers in this private auction. Corresponds to the JSON property openAuctionAllowed

Returns:

  • (Boolean)


1564
1565
1566
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1564

def open_auction_allowed
  @open_auction_allowed
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1572
1573
1574
1575
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1572

def update!(**args)
  @floor_price = args[:floor_price] if args.key?(:floor_price)
  @open_auction_allowed = args[:open_auction_allowed] if args.key?(:open_auction_allowed)
end