Class: Google::Apis::AuthorizedbuyersmarketplaceV1::PublisherProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb

Overview

The values in the publisher profile are supplied by the publisher. All fields are not filterable unless stated otherwise.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublisherProfile

Returns a new instance of PublisherProfile.



1909
1910
1911
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1909

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audience_descriptionString

Description on the publisher's audience. Corresponds to the JSON property audienceDescription

Returns:

  • (String)


1814
1815
1816
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1814

def audience_description
  @audience_description
end

#direct_deals_contactString

Contact information for direct reservation deals. This is free text entered by the publisher and may include information like names, phone numbers and email addresses. Corresponds to the JSON property directDealsContact

Returns:

  • (String)


1821
1822
1823
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1821

def direct_deals_contact
  @direct_deals_contact
end

#display_nameString

Display name of the publisher profile. Can be used to filter the response of the publisherProfiles.list method. Corresponds to the JSON property displayName

Returns:

  • (String)


1827
1828
1829
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1827

def display_name
  @display_name
end

#domainsArray<String>

The list of domains represented in this publisher profile. Empty if this is a parent profile. These are top private domains, meaning that these will not contain a string like "photos.google.co.uk/123", but will instead contain " google.co.uk". Can be used to filter the response of the publisherProfiles. list method. Corresponds to the JSON property domains

Returns:

  • (Array<String>)


1836
1837
1838
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1836

def domains
  @domains
end

#is_parentBoolean Also known as: is_parent?

Indicates if this profile is the parent profile of the seller. A parent profile represents all the inventory from the seller, as opposed to child profile that is created to brand a portion of inventory. One seller has only one parent publisher profile, and can have multiple child profiles. See https:/ /support.google.com/admanager/answer/6035806 for details. Can be used to filter the response of the publisherProfiles.list method by setting the filter to "is_parent: true". Corresponds to the JSON property isParent

Returns:

  • (Boolean)


1847
1848
1849
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1847

def is_parent
  @is_parent
end

#logo_urlString

A Google public URL to the logo for this publisher profile. The logo is stored as a PNG, JPG, or GIF image. Corresponds to the JSON property logoUrl

Returns:

  • (String)


1854
1855
1856
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1854

def logo_url
  @logo_url
end

#media_kit_urlString

URL to additional marketing and sales materials. Corresponds to the JSON property mediaKitUrl

Returns:

  • (String)


1859
1860
1861
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1859

def media_kit_url
  @media_kit_url
end

#mobile_appsArray<Google::Apis::AuthorizedbuyersmarketplaceV1::PublisherProfileMobileApplication>

The list of apps represented in this publisher profile. Empty if this is a parent profile. Corresponds to the JSON property mobileApps



1865
1866
1867
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1865

def mobile_apps
  @mobile_apps
end

#nameString

Name of the publisher profile. Format: buyers/buyer/publisherProfiles/ publisher_profile` Corresponds to the JSON propertyname`

Returns:

  • (String)


1871
1872
1873
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1871

def name
  @name
end

#overviewString

Overview of the publisher. Corresponds to the JSON property overview

Returns:

  • (String)


1876
1877
1878
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1876

def overview
  @overview
end

#pitch_statementString

Statement explaining what's unique about publisher's business, and why buyers should partner with the publisher. Corresponds to the JSON property pitchStatement

Returns:

  • (String)


1882
1883
1884
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1882

def pitch_statement
  @pitch_statement
end

#programmatic_deals_contactString

Contact information for programmatic deals. This is free text entered by the publisher and may include information like names, phone numbers and email addresses. Corresponds to the JSON property programmaticDealsContact

Returns:

  • (String)


1889
1890
1891
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1889

def programmatic_deals_contact
  @programmatic_deals_contact
end

#publisher_codeString

A unique identifying code for the seller. This value is the same for all of the seller's parent and child publisher profiles. Can be used to filter the response of the publisherProfiles.list method. Corresponds to the JSON property publisherCode

Returns:

  • (String)


1896
1897
1898
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1896

def publisher_code
  @publisher_code
end

#sample_page_urlString

URL to a sample content page. Corresponds to the JSON property samplePageUrl

Returns:

  • (String)


1901
1902
1903
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1901

def sample_page_url
  @sample_page_url
end

#top_headlinesArray<String>

Up to three key metrics and rankings. For example, "#1 Mobile News Site for 20 Straight Months". Corresponds to the JSON property topHeadlines

Returns:

  • (Array<String>)


1907
1908
1909
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1907

def top_headlines
  @top_headlines
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1914
1915
1916
1917
1918
1919
1920
1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1914

def update!(**args)
  @audience_description = args[:audience_description] if args.key?(:audience_description)
  @direct_deals_contact = args[:direct_deals_contact] if args.key?(:direct_deals_contact)
  @display_name = args[:display_name] if args.key?(:display_name)
  @domains = args[:domains] if args.key?(:domains)
  @is_parent = args[:is_parent] if args.key?(:is_parent)
  @logo_url = args[:logo_url] if args.key?(:logo_url)
  @media_kit_url = args[:media_kit_url] if args.key?(:media_kit_url)
  @mobile_apps = args[:mobile_apps] if args.key?(:mobile_apps)
  @name = args[:name] if args.key?(:name)
  @overview = args[:overview] if args.key?(:overview)
  @pitch_statement = args[:pitch_statement] if args.key?(:pitch_statement)
  @programmatic_deals_contact = args[:programmatic_deals_contact] if args.key?(:programmatic_deals_contact)
  @publisher_code = args[:publisher_code] if args.key?(:publisher_code)
  @sample_page_url = args[:sample_page_url] if args.key?(:sample_page_url)
  @top_headlines = args[:top_headlines] if args.key?(:top_headlines)
end