Class: Google::Apis::AuthorizedbuyersmarketplaceV1::PublisherProfileMobileApplication

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb

Overview

A mobile application that contains a external app ID, name, and app store.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublisherProfileMobileApplication

Returns a new instance of PublisherProfileMobileApplication.



1954
1955
1956
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1954

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_storeString

The app store the app belongs to. Can be used to filter the response of the publisherProfiles.list method. Corresponds to the JSON property appStore

Returns:

  • (String)


1941
1942
1943
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1941

def app_store
  @app_store
end

#external_app_idString

The external ID for the app from its app store. Can be used to filter the response of the publisherProfiles.list method. Corresponds to the JSON property externalAppId

Returns:

  • (String)


1947
1948
1949
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1947

def external_app_id
  @external_app_id
end

#nameString

The name of the app. Corresponds to the JSON property name

Returns:

  • (String)


1952
1953
1954
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1952

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1959
1960
1961
1962
1963
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1959

def update!(**args)
  @app_store = args[:app_store] if args.key?(:app_store)
  @external_app_id = args[:external_app_id] if args.key?(:external_app_id)
  @name = args[:name] if args.key?(:name)
end