Class: Google::Apis::AuthorizedbuyersmarketplaceV1::SendRfpRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb

Overview

Request to send an RFP. All fields in this request are proposed to publisher and subject to changes by publisher during later negotiation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SendRfpRequest

Returns a new instance of SendRfpRequest.



2103
2104
2105
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 2103

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#buyer_contactsArray<Google::Apis::AuthorizedbuyersmarketplaceV1::Contact>

Contact information for the buyer. Corresponds to the JSON property buyerContacts



2037
2038
2039
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 2037

def buyer_contacts
  @buyer_contacts
end

#clientString

If the current buyer is sending the RFP on behalf of its client, use this field to specify the name of the client in the format: buyers/accountId/ clients/clientAccountid`. Corresponds to the JSON propertyclient`

Returns:

  • (String)


2044
2045
2046
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 2044

def client
  @client
end

#display_nameString

Required. The display name of the proposal being created by this RFP. Corresponds to the JSON property displayName

Returns:

  • (String)


2049
2050
2051
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 2049

def display_name
  @display_name
end

#estimated_gross_spendGoogle::Apis::AuthorizedbuyersmarketplaceV1::Money

Represents an amount of money with its currency type. Corresponds to the JSON property estimatedGrossSpend



2054
2055
2056
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 2054

def estimated_gross_spend
  @estimated_gross_spend
end

#flight_end_timeString

Required. Proposed flight end time of the RFP. A timestamp in RFC3339 UTC " Zulu" format. Note that the specified value will be truncated to a granularity of one second. Corresponds to the JSON property flightEndTime

Returns:

  • (String)


2061
2062
2063
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 2061

def flight_end_time
  @flight_end_time
end

#flight_start_timeString

Required. Proposed flight start time of the RFP. A timestamp in RFC3339 UTC " Zulu" format. Note that the specified value will be truncated to a granularity of one second. Corresponds to the JSON property flightStartTime

Returns:

  • (String)


2068
2069
2070
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 2068

def flight_start_time
  @flight_start_time
end

#geo_targetingGoogle::Apis::AuthorizedbuyersmarketplaceV1::CriteriaTargeting

Generic targeting used for targeting dimensions that contains a list of included and excluded numeric IDs. This cannot be filtered using list filter syntax. Corresponds to the JSON property geoTargeting



2075
2076
2077
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 2075

def geo_targeting
  @geo_targeting
end

#inventory_size_targetingGoogle::Apis::AuthorizedbuyersmarketplaceV1::InventorySizeTargeting

Represents the size of an ad unit that can be targeted on a bid request. Corresponds to the JSON property inventorySizeTargeting



2080
2081
2082
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 2080

def inventory_size_targeting
  @inventory_size_targeting
end

#noteString

A message that is sent to the publisher. Maximum length is 1024 characters. Corresponds to the JSON property note

Returns:

  • (String)


2085
2086
2087
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 2085

def note
  @note
end

#preferred_deal_termsGoogle::Apis::AuthorizedbuyersmarketplaceV1::PreferredDealTerms

Pricing terms for Preferred Deals. Corresponds to the JSON property preferredDealTerms



2090
2091
2092
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 2090

def preferred_deal_terms
  @preferred_deal_terms
end

#programmatic_guaranteed_termsGoogle::Apis::AuthorizedbuyersmarketplaceV1::ProgrammaticGuaranteedTerms

Pricing terms for Programmatic Guaranteed Deals. Corresponds to the JSON property programmaticGuaranteedTerms



2095
2096
2097
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 2095

def programmatic_guaranteed_terms
  @programmatic_guaranteed_terms
end

#publisher_profileString

Required. The profile of the publisher who will receive this RFP in the format: buyers/accountId/publisherProfiles/publisherProfileId`. Corresponds to the JSON propertypublisherProfile`

Returns:

  • (String)


2101
2102
2103
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 2101

def publisher_profile
  @publisher_profile
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2108
2109
2110
2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 2108

def update!(**args)
  @buyer_contacts = args[:buyer_contacts] if args.key?(:buyer_contacts)
  @client = args[:client] if args.key?(:client)
  @display_name = args[:display_name] if args.key?(:display_name)
  @estimated_gross_spend = args[:estimated_gross_spend] if args.key?(:estimated_gross_spend)
  @flight_end_time = args[:flight_end_time] if args.key?(:flight_end_time)
  @flight_start_time = args[:flight_start_time] if args.key?(:flight_start_time)
  @geo_targeting = args[:geo_targeting] if args.key?(:geo_targeting)
  @inventory_size_targeting = args[:inventory_size_targeting] if args.key?(:inventory_size_targeting)
  @note = args[:note] if args.key?(:note)
  @preferred_deal_terms = args[:preferred_deal_terms] if args.key?(:preferred_deal_terms)
  @programmatic_guaranteed_terms = args[:programmatic_guaranteed_terms] if args.key?(:programmatic_guaranteed_terms)
  @publisher_profile = args[:publisher_profile] if args.key?(:publisher_profile)
end