Class: Google::Apis::AuthorizedbuyersmarketplaceV1::TechnologyTargeting
- Inherits:
-
Object
- Object
- Google::Apis::AuthorizedbuyersmarketplaceV1::TechnologyTargeting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb
Overview
Represents targeting about various types of technology.
Instance Attribute Summary collapse
-
#device_capability_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1::CriteriaTargeting
Generic targeting used for targeting dimensions that contains a list of included and excluded numeric IDs.
-
#device_category_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1::CriteriaTargeting
Generic targeting used for targeting dimensions that contains a list of included and excluded numeric IDs.
-
#operating_system_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1::OperatingSystemTargeting
Represents targeting information for operating systems.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TechnologyTargeting
constructor
A new instance of TechnologyTargeting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TechnologyTargeting
Returns a new instance of TechnologyTargeting.
2195 2196 2197 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 2195 def initialize(**args) update!(**args) end |
Instance Attribute Details
#device_capability_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1::CriteriaTargeting
Generic targeting used for targeting dimensions that contains a list of
included and excluded numeric IDs. This cannot be filtered using list filter
syntax.
Corresponds to the JSON property deviceCapabilityTargeting
2181 2182 2183 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 2181 def device_capability_targeting @device_capability_targeting end |
#device_category_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1::CriteriaTargeting
Generic targeting used for targeting dimensions that contains a list of
included and excluded numeric IDs. This cannot be filtered using list filter
syntax.
Corresponds to the JSON property deviceCategoryTargeting
2188 2189 2190 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 2188 def device_category_targeting @device_category_targeting end |
#operating_system_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1::OperatingSystemTargeting
Represents targeting information for operating systems.
Corresponds to the JSON property operatingSystemTargeting
2193 2194 2195 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 2193 def @operating_system_targeting end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2200 2201 2202 2203 2204 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 2200 def update!(**args) @device_capability_targeting = args[:device_capability_targeting] if args.key?(:device_capability_targeting) @device_category_targeting = args[:device_category_targeting] if args.key?(:device_category_targeting) @operating_system_targeting = args[:operating_system_targeting] if args.key?(:operating_system_targeting) end |