Class: Google::Apis::AuthorizedbuyersmarketplaceV1::UnsubscribeClientsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb

Overview

Request message for UnsubscribeAuctionPackage.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UnsubscribeClientsRequest

Returns a new instance of UnsubscribeClientsRequest.



2301
2302
2303
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 2301

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clientsArray<String>

Optional. A list of client buyers to unsubscribe from the auction package, with client buyer in the format buyers/accountId/clients/clientAccountId`. Corresponds to the JSON propertyclients`

Returns:

  • (Array<String>)


2299
2300
2301
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 2299

def clients
  @clients
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2306
2307
2308
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 2306

def update!(**args)
  @clients = args[:clients] if args.key?(:clients)
end