Class: Google::Apis::AuthorizedbuyersmarketplaceV1::AuctionPackage
- Inherits:
-
Object
- Object
- Google::Apis::AuthorizedbuyersmarketplaceV1::AuctionPackage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb
Overview
Defines a segment of inventory that buyer wants to buy. It's created by buyer and could be shared with multiple buyers.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#creator ⇒ String
Output only.
-
#deal_owner_seat_id ⇒ String
Output only.
-
#description ⇒ String
Output only.
-
#display_name ⇒ String
The display_name assigned to the auction package.
-
#eligible_seat_ids ⇒ Array<String>
Output only.
-
#floor_price_cpm ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1::Money
Represents an amount of money with its currency type.
-
#name ⇒ String
Immutable.
-
#subscribed_buyers ⇒ Array<String>
Output only.
-
#subscribed_clients ⇒ Array<String>
Output only.
-
#subscribed_media_planners ⇒ Array<Google::Apis::AuthorizedbuyersmarketplaceV1::MediaPlanner>
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AuctionPackage
constructor
A new instance of AuctionPackage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AuctionPackage
Returns a new instance of AuctionPackage.
226 227 228 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 226 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Time the auction package was created.
Corresponds to the JSON property createTime
153 154 155 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 153 def create_time @create_time end |
#creator ⇒ String
Output only. The buyer that created this auction package. Format: buyers/
buyerAccountId`
Corresponds to the JSON propertycreator`
159 160 161 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 159 def creator @creator end |
#deal_owner_seat_id ⇒ String
Output only. If set, this field contains the DSP specific seat id set by the
media planner account that is considered the owner of this deal. The seat ID
is in the calling DSP's namespace.
Corresponds to the JSON property dealOwnerSeatId
166 167 168 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 166 def deal_owner_seat_id @deal_owner_seat_id end |
#description ⇒ String
Output only. A description of the auction package.
Corresponds to the JSON property description
171 172 173 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 171 def description @description end |
#display_name ⇒ String
The display_name assigned to the auction package.
Corresponds to the JSON property displayName
176 177 178 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 176 def display_name @display_name end |
#eligible_seat_ids ⇒ Array<String>
Output only. If set, this field identifies a seat that the media planner
selected as the owner of this auction package. This is a seat ID in the DSP's
namespace that was provided to the media planner.
Corresponds to the JSON property eligibleSeatIds
183 184 185 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 183 def eligible_seat_ids @eligible_seat_ids end |
#floor_price_cpm ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property floorPriceCpm
188 189 190 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 188 def floor_price_cpm @floor_price_cpm end |
#name ⇒ String
Immutable. The unique identifier for the auction package. Format: buyers/
accountId/auctionPackages/auctionPackageId`The auction_package_id part of
name is sent in the BidRequest to all RTB bidders and is returned as deal_id
by the bidder in the BidResponse.
Corresponds to the JSON propertyname`
196 197 198 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 196 def name @name end |
#subscribed_buyers ⇒ Array<String>
Output only. The list of buyers that are subscribed to the AuctionPackage.
This field is only populated when calling as a bidder. Format: buyers/
buyerAccountId`
Corresponds to the JSON propertysubscribedBuyers`
203 204 205 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 203 def subscribed_buyers @subscribed_buyers end |
#subscribed_clients ⇒ Array<String>
Output only. When calling as a buyer, the list of clients of the current buyer
that are subscribed to the AuctionPackage. When calling as a bidder, the list
of clients that are subscribed to the AuctionPackage owned by the bidder or
its buyers. Format: buyers/buyerAccountId/clients/clientAccountId`
Corresponds to the JSON propertysubscribedClients`
211 212 213 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 211 def subscribed_clients @subscribed_clients end |
#subscribed_media_planners ⇒ Array<Google::Apis::AuthorizedbuyersmarketplaceV1::MediaPlanner>
Output only. The list of media planners that are subscribed to the
AuctionPackage. This field is only populated when calling as a bidder.
Corresponds to the JSON property subscribedMediaPlanners
217 218 219 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 217 def subscribed_media_planners @subscribed_media_planners end |
#update_time ⇒ String
Output only. Time the auction package was last updated. This value is only
increased when this auction package is updated but never when a buyer
subscribed.
Corresponds to the JSON property updateTime
224 225 226 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 224 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 231 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @creator = args[:creator] if args.key?(:creator) @deal_owner_seat_id = args[:deal_owner_seat_id] if args.key?(:deal_owner_seat_id) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @eligible_seat_ids = args[:eligible_seat_ids] if args.key?(:eligible_seat_ids) @floor_price_cpm = args[:floor_price_cpm] if args.key?(:floor_price_cpm) @name = args[:name] if args.key?(:name) @subscribed_buyers = args[:subscribed_buyers] if args.key?(:subscribed_buyers) @subscribed_clients = args[:subscribed_clients] if args.key?(:subscribed_clients) @subscribed_media_planners = args[:subscribed_media_planners] if args.key?(:subscribed_media_planners) @update_time = args[:update_time] if args.key?(:update_time) end |