Class: Google::Apis::AuthorizedbuyersmarketplaceV1::Client
- Inherits:
-
Object
- Object
- Google::Apis::AuthorizedbuyersmarketplaceV1::Client
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb
Overview
A client represents an agency, a brand, or an advertiser customer of the buyer. Based on the client's role, its client users will have varying levels of restricted access to the Marketplace and certain other sections of the Authorized Buyers UI.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Required.
-
#name ⇒ String
Output only.
-
#partner_client_id ⇒ String
Arbitrary unique identifier provided by the buyer.
-
#role ⇒ String
Required.
-
#seller_visible ⇒ Boolean
(also: #seller_visible?)
Whether the client will be visible to sellers.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Client
constructor
A new instance of Client.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Client
Returns a new instance of Client.
342 343 344 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 342 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Required. Display name shown to publishers. Must be unique for clients without
partnerClientId specified. Maximum length of 255 characters is allowed.
Corresponds to the JSON property displayName
309 310 311 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 309 def display_name @display_name end |
#name ⇒ String
Output only. The resource name of the client. Format: buyers/accountId/
clients/clientAccountId`
Corresponds to the JSON propertyname`
315 316 317 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 315 def name @name end |
#partner_client_id ⇒ String
Arbitrary unique identifier provided by the buyer. This field can be used to
associate a client with an identifier in the namespace of the buyer, lookup
clients by that identifier and verify whether an Authorized Buyers account of
the client already exists. If present, must be unique across all the clients.
Corresponds to the JSON property partnerClientId
323 324 325 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 323 def partner_client_id @partner_client_id end |
#role ⇒ String
Required. The role assigned to the client. Each role implies a set of
permissions granted to the client.
Corresponds to the JSON property role
329 330 331 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 329 def role @role end |
#seller_visible ⇒ Boolean Also known as: seller_visible?
Whether the client will be visible to sellers.
Corresponds to the JSON property sellerVisible
334 335 336 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 334 def seller_visible @seller_visible end |
#state ⇒ String
Output only. The state of the client.
Corresponds to the JSON property state
340 341 342 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 340 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
347 348 349 350 351 352 353 354 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 347 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @partner_client_id = args[:partner_client_id] if args.key?(:partner_client_id) @role = args[:role] if args.key?(:role) @seller_visible = args[:seller_visible] if args.key?(:seller_visible) @state = args[:state] if args.key?(:state) end |