Class: Google::Apis::AuthorizedbuyersmarketplaceV1::ClientUser
- Inherits:
-
Object
- Object
- Google::Apis::AuthorizedbuyersmarketplaceV1::ClientUser
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb
Overview
A user of a client who has restricted access to the Marketplace and certain other sections of the Authorized Buyers UI based on the role granted to the associated client.
Instance Attribute Summary collapse
-
#email ⇒ String
Required.
-
#name ⇒ String
Output only.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ClientUser
constructor
A new instance of ClientUser.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ClientUser
Returns a new instance of ClientUser.
380 381 382 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 380 def initialize(**args) update!(**args) end |
Instance Attribute Details
#email ⇒ String
Required. The client user's email address that has to be unique across all
users for the same client.
Corresponds to the JSON property email
367 368 369 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 367 def email @email end |
#name ⇒ String
Output only. The resource name of the client user. Format: buyers/accountId/
clients/clientAccountId/users/userId`
Corresponds to the JSON propertyname`
373 374 375 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 373 def name @name end |
#state ⇒ String
Output only. The state of the client user.
Corresponds to the JSON property state
378 379 380 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 378 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
385 386 387 388 389 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 385 def update!(**args) @email = args[:email] if args.key?(:email) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) end |