Class: Google::Apis::AuthorizedbuyersmarketplaceV1::ListClientUsersResponse
- Inherits:
-
Object
- Object
- Google::Apis::AuthorizedbuyersmarketplaceV1::ListClientUsersResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb
Overview
Response message for the list method.
Instance Attribute Summary collapse
-
#client_users ⇒ Array<Google::Apis::AuthorizedbuyersmarketplaceV1::ClientUser>
The returned list of client users.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListClientUsersResponse
constructor
A new instance of ListClientUsersResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListClientUsersResponse
Returns a new instance of ListClientUsersResponse.
1072 1073 1074 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1072 def initialize(**args) update!(**args) end |
Instance Attribute Details
#client_users ⇒ Array<Google::Apis::AuthorizedbuyersmarketplaceV1::ClientUser>
The returned list of client users.
Corresponds to the JSON property clientUsers
1063 1064 1065 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1063 def client_users @client_users end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
ListClientUsersRequest.pageToken field in the subsequent call to the list
method to retrieve the next page of results.
Corresponds to the JSON property nextPageToken
1070 1071 1072 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1070 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1077 1078 1079 1080 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1077 def update!(**args) @client_users = args[:client_users] if args.key?(:client_users) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |