Class: Google::Apis::AuthorizedbuyersmarketplaceV1::ListClientsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AuthorizedbuyersmarketplaceV1::ListClientsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb
Overview
Response message for the list method.
Instance Attribute Summary collapse
-
#clients ⇒ Array<Google::Apis::AuthorizedbuyersmarketplaceV1::Client>
The returned list of clients.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListClientsResponse
constructor
A new instance of ListClientsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListClientsResponse
Returns a new instance of ListClientsResponse.
1099 1100 1101 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1099 def initialize(**args) update!(**args) end |
Instance Attribute Details
#clients ⇒ Array<Google::Apis::AuthorizedbuyersmarketplaceV1::Client>
The returned list of clients.
Corresponds to the JSON property clients
1090 1091 1092 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1090 def clients @clients end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
ListClientsRequest.pageToken field in the subsequent call to the list method
to retrieve the next page of results.
Corresponds to the JSON property nextPageToken
1097 1098 1099 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1097 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1104 1105 1106 1107 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1104 def update!(**args) @clients = args[:clients] if args.key?(:clients) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |