Class: Google::Apis::AuthorizedbuyersmarketplaceV1::Proposal
- Inherits:
-
Object
- Object
- Google::Apis::AuthorizedbuyersmarketplaceV1::Proposal
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1/representations.rb
Overview
Represents a proposal in the Marketplace. A proposal is the unit of negotiation between a seller and a buyer.
Instance Attribute Summary collapse
-
#billed_buyer ⇒ String
Output only.
-
#buyer ⇒ String
Output only.
-
#buyer_contacts ⇒ Array<Google::Apis::AuthorizedbuyersmarketplaceV1::Contact>
Contact information for the buyer.
-
#buyer_private_data ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1::PrivateData
Buyers are allowed to store certain types of private data in a proposal.
-
#client ⇒ String
Output only.
-
#deal_type ⇒ String
Output only.
-
#display_name ⇒ String
Output only.
-
#is_renegotiating ⇒ Boolean
(also: #is_renegotiating?)
Output only.
-
#last_updater_or_commentor_role ⇒ String
Output only.
-
#name ⇒ String
Immutable.
-
#notes ⇒ Array<Google::Apis::AuthorizedbuyersmarketplaceV1::Note>
A list of notes from the buyer and the seller attached to this proposal.
-
#originator_role ⇒ String
Output only.
-
#pausing_consented ⇒ Boolean
(also: #pausing_consented?)
Whether pausing is allowed for the proposal.
-
#proposal_revision ⇒ Fixnum
Output only.
-
#publisher_profile ⇒ String
Immutable.
-
#seller_contacts ⇒ Array<Google::Apis::AuthorizedbuyersmarketplaceV1::Contact>
Output only.
-
#state ⇒ String
Output only.
-
#terms_and_conditions ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Proposal
constructor
A new instance of Proposal.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Proposal
Returns a new instance of Proposal.
1778 1779 1780 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1778 def initialize(**args) update!(**args) end |
Instance Attribute Details
#billed_buyer ⇒ String
Output only. When the client field is populated, this field refers to the
buyer who creates and manages the client buyer and gets billed on behalf of
the client buyer; when the buyer field is populated, this field is the same
value as buyer. Format : buyers/buyerAccountId`
Corresponds to the JSON propertybilledBuyer`
1665 1666 1667 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1665 def billed_buyer @billed_buyer end |
#buyer ⇒ String
Output only. Refers to a buyer in The Realtime-bidding API. Format: buyers/
buyerAccountId`
Corresponds to the JSON propertybuyer`
1671 1672 1673 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1671 def buyer @buyer end |
#buyer_contacts ⇒ Array<Google::Apis::AuthorizedbuyersmarketplaceV1::Contact>
Contact information for the buyer.
Corresponds to the JSON property buyerContacts
1676 1677 1678 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1676 def buyer_contacts @buyer_contacts end |
#buyer_private_data ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1::PrivateData
Buyers are allowed to store certain types of private data in a proposal.
Corresponds to the JSON property buyerPrivateData
1681 1682 1683 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1681 def buyer_private_data @buyer_private_data end |
#client ⇒ String
Output only. Refers to a Client. Format: buyers/buyerAccountId/clients/
clientAccountid`
Corresponds to the JSON propertyclient`
1687 1688 1689 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1687 def client @client end |
#deal_type ⇒ String
Output only. Type of deal the proposal contains.
Corresponds to the JSON property dealType
1692 1693 1694 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1692 def deal_type @deal_type end |
#display_name ⇒ String
Output only. The descriptive name for the proposal. Maximum length of 255
unicode characters is allowed. Control characters are not allowed. Buyers
cannot update this field. Note: Not to be confused with name, which is a
unique identifier of the proposal.
Corresponds to the JSON property displayName
1700 1701 1702 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1700 def display_name @display_name end |
#is_renegotiating ⇒ Boolean Also known as: is_renegotiating?
Output only. True if the proposal was previously finalized and is now being
renegotiated.
Corresponds to the JSON property isRenegotiating
1706 1707 1708 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1706 def is_renegotiating @is_renegotiating end |
#last_updater_or_commentor_role ⇒ String
Output only. The role of the last user that either updated the proposal or
left a comment.
Corresponds to the JSON property lastUpdaterOrCommentorRole
1713 1714 1715 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1713 def last_updater_or_commentor_role @last_updater_or_commentor_role end |
#name ⇒ String
Immutable. The name of the proposal serving as a unique identifier. Format:
buyers/accountId/proposals/proposalId
Corresponds to the JSON property name
1719 1720 1721 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1719 def name @name end |
#notes ⇒ Array<Google::Apis::AuthorizedbuyersmarketplaceV1::Note>
A list of notes from the buyer and the seller attached to this proposal.
Corresponds to the JSON property notes
1724 1725 1726 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1724 def notes @notes end |
#originator_role ⇒ String
Output only. Indicates whether the buyer/seller created the proposal.
Corresponds to the JSON property originatorRole
1729 1730 1731 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1729 def originator_role @originator_role end |
#pausing_consented ⇒ Boolean Also known as: pausing_consented?
Whether pausing is allowed for the proposal. This is a negotiable term between
buyers and publishers.
Corresponds to the JSON property pausingConsented
1735 1736 1737 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1735 def @pausing_consented end |
#proposal_revision ⇒ Fixnum
Output only. The revision number for the proposal. Each update to the proposal
or deal causes the proposal revision number to auto-increment. The buyer keeps
track of the last revision number they know of and pass it in when making an
update. If the head revision number on the server has since incremented, then
an ABORTED error is returned during the update operation to let the buyer know
that a subsequent update was made.
Corresponds to the JSON property proposalRevision
1746 1747 1748 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1746 def proposal_revision @proposal_revision end |
#publisher_profile ⇒ String
Immutable. Reference to the seller on the proposal. Format: buyers/
buyerAccountId/publisherProfiles/publisherProfileId`Note: This field may
be set only when creating the resource. Modifying this field while updating
the resource will result in an error.
Corresponds to the JSON propertypublisherProfile`
1754 1755 1756 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1754 def publisher_profile @publisher_profile end |
#seller_contacts ⇒ Array<Google::Apis::AuthorizedbuyersmarketplaceV1::Contact>
Output only. Contact information for the seller.
Corresponds to the JSON property sellerContacts
1759 1760 1761 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1759 def seller_contacts @seller_contacts end |
#state ⇒ String
Output only. Indicates the state of the proposal.
Corresponds to the JSON property state
1764 1765 1766 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1764 def state @state end |
#terms_and_conditions ⇒ String
Output only. The terms and conditions associated with this proposal. Accepting
a proposal implies acceptance of this field. This is created by the seller,
the buyer can only view it.
Corresponds to the JSON property termsAndConditions
1771 1772 1773 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1771 def terms_and_conditions @terms_and_conditions end |
#update_time ⇒ String
Output only. The time when the proposal was last revised.
Corresponds to the JSON property updateTime
1776 1777 1778 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1776 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1/classes.rb', line 1783 def update!(**args) @billed_buyer = args[:billed_buyer] if args.key?(:billed_buyer) @buyer = args[:buyer] if args.key?(:buyer) @buyer_contacts = args[:buyer_contacts] if args.key?(:buyer_contacts) @buyer_private_data = args[:buyer_private_data] if args.key?(:buyer_private_data) @client = args[:client] if args.key?(:client) @deal_type = args[:deal_type] if args.key?(:deal_type) @display_name = args[:display_name] if args.key?(:display_name) @is_renegotiating = args[:is_renegotiating] if args.key?(:is_renegotiating) @last_updater_or_commentor_role = args[:last_updater_or_commentor_role] if args.key?(:last_updater_or_commentor_role) @name = args[:name] if args.key?(:name) @notes = args[:notes] if args.key?(:notes) @originator_role = args[:originator_role] if args.key?(:originator_role) @pausing_consented = args[:pausing_consented] if args.key?(:pausing_consented) @proposal_revision = args[:proposal_revision] if args.key?(:proposal_revision) @publisher_profile = args[:publisher_profile] if args.key?(:publisher_profile) @seller_contacts = args[:seller_contacts] if args.key?(:seller_contacts) @state = args[:state] if args.key?(:state) @terms_and_conditions = args[:terms_and_conditions] if args.key?(:terms_and_conditions) @update_time = args[:update_time] if args.key?(:update_time) end |